<?php
namespace HCM\FPA\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\Repositories;
use HCM\Util\HCMParameters;

class AprovacaoCalculoRepository {
    
    protected  $connection;
    public function __construct(Connection $connection, EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
    }
    
    public function getVinculoEventosNaoAprovados($parameters, $conditions){
        $query = "SELECT *
                    FROM (SELECT GPE_VINCULOM.NRVINCULOM,
                                 GPE_VINCULOM.NMVINCULOM,
                                 GPE_VINCULOM.DTADMISSAOVINC,
                                 GPE_VINCULOM.DTRESCISAOVINC,
                                 FPA_TIPOMOVIMENT.NMTIPOMOVIMENT,
                                 FPA_ITECALCFOLHA.NREVENTOM,
                                 FPA_EVENTOH.NMEVENTOH,
                                 FPA_CALCULOFOLHA.NRTIPOMOVIMENT,
                                 FPA_CALCULOFOLHA.NRCALCULOFOLHA,
                                 FPA_ITECALCFOLHA.VREVENTOFOLHA,
                                 FPA_ITECALCFOLHA.DTOCORRENCIA
                            FROM FPA_ITECALCFOLHA
                            JOIN GPE_VINCULOM ON GPE_VINCULOM.NRVINCULOM = FPA_ITECALCFOLHA.NRVINCULOM 
                                             AND GPE_VINCULOM.NRORG = FPA_ITECALCFOLHA.NRORG
                                             AND (GPE_VINCULOM.DTRESCISAOVINC <= LAST_DAY(:P_DTMESCOMPETENC) OR GPE_VINCULOM.DTRESCISAOVINC IS NULL)
                            JOIN GPE_VINCULOH ON GPE_VINCULOH.NRVINCULOM = GPE_VINCULOM.NRVINCULOM
                                             AND GPE_VINCULOH.NRORG = GPE_VINCULOM.NRORG
                                             AND GPE_VINCULOH.DTMESCOMPETENC = (SELECT MAX(VH.DTMESCOMPETENC)
                                                                                  FROM GPE_VINCULOH VH
                                                                                 WHERE VH.NRVINCULOM = GPE_VINCULOH.NRVINCULOM
                                                                                   AND VH.NRORG = GPE_VINCULOH.NRORG
                                                                                   AND VH.DTMESCOMPETENC <= :P_DTMESCOMPETENC) 
                            JOIN FPA_EVENTOH ON FPA_EVENTOH.NREVENTOM =  FPA_ITECALCFOLHA.NREVENTOM
                                            AND (FPA_EVENTOH.NRORG = :P_NRORG OR FPA_EVENTOH.NRORG = :P_NRORG_PADRAO)
                                            AND FPA_EVENTOH.DTMESCOMPETENC = (SELECT MAX(EH.DTMESCOMPETENC) 
                                                                                FROM FPA_EVENTOH EH
                                                                               WHERE EH.NREVENTOM = FPA_EVENTOH.NREVENTOM
                                                                                 AND EH.NRORG = FPA_EVENTOH.NRORG
                                                                                 AND EH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                            JOIN FPA_CALCULOFOLHA ON FPA_CALCULOFOLHA.NRCALCULOFOLHA = FPA_ITECALCFOLHA.NRCALCULOFOLHA
                                                 AND FPA_CALCULOFOLHA.NRORG = FPA_ITECALCFOLHA.NRORG
                                                 AND FPA_CALCULOFOLHA.DTOCORRENCIA = :P_DTMESCOMPETENC
                                                 AND FPA_CALCULOFOLHA.NRTPMODALIDCAL = :P_NRTPMODALIDCALC
                                                 AND FPA_CALCULOFOLHA.NROCORRECAL = :P_NROCORRECAL
                            JOIN FPA_TIPOMOVIMENT ON FPA_TIPOMOVIMENT.NRTIPOMOVIMENT = FPA_CALCULOFOLHA.NRTIPOMOVIMENT
                            JOIN ESO_PARAMETRO ON ESO_PARAMETRO.NRESTRUTURAM = GPE_VINCULOH.NRESTRUTLEGAL 
                                              AND ESO_PARAMETRO.NRORG = GPE_VINCULOH.NRORG  
                           WHERE FPA_ITECALCFOLHA.NRORG = :P_NRORG
                             AND FPA_ITECALCFOLHA.NREVENTOM = DECODE(FPA_CALCULOFOLHA.NRTIPOMOVIMENT, 1, 3050, 2, 3030)
                             AND NOT EXISTS(SELECT 1
                                              FROM FPA_ITECALCFOLHA IC  
                                             WHERE IC.NRVINCULOM = FPA_ITECALCFOLHA.NRVINCULOM
                                               AND IC.NRORG = FPA_ITECALCFOLHA.NRORG
                                               AND IC.NRCALCULOFOLHA = FPA_ITECALCFOLHA.NRCALCULOFOLHA
                                               AND IC.NREVENTOM = 3035)
                             AND ((FPA_ITECALCFOLHA.NREVENTOM = 3050 AND ESO_PARAMETRO.IDAPROVACALCRESC = 'S') 
                                  OR (FPA_ITECALCFOLHA.NREVENTOM = 3030 AND ESO_PARAMETRO.IDAPROVACALCFERIAS = 'S' ))
                        ORDER BY GPE_VINCULOM.NMVINCULOM) 
                   WHERE 1 = 1
                   ".$conditions;
        $params = array("P_NRORG"           => $parameters['P_NRORG'],
                        "P_DTMESCOMPETENC"  => $parameters['P_DTMESCOMPETENC'],
                        "P_NRORG_PADRAO"    => $parameters['P_NRORG_PADRAO'],
                        "P_NRTPMODALIDCALC" => $this->hcmParameters->getNrModalidadeCalculo(),
                        "P_NROCORRECAL"     => $this->hcmParameters->getOcorrenciaCalculo());
                        
        //$result = $this->entityManager->createQuery($query)->execute($params);
        //return $result[0];
        return $this->connection->fetchAll($query, $params);
        
    }
}